Imaging
=======

.. toctree::
   :maxdepth: 2

   detectors
   filters
   crop_and_resize_algorithms
   detection_algorithms
   how_to_upload_images
   how_upload_works_in_thumbor
   image_loader
   image_storage
   lazy_detection
   posting_putting_deleting
   result_storage
   optimizers
